#!/usr/bin/env python
from cryptography.fernet import Fernet
import os
import shutil
import sys
from PyQt5.QtWidgets import QApplication, QMainWindow, QDesktopWidget, QFileDialog, QMessageBox, QPushButton, QLabel
from openjournal.ui.MainWindow import Ui_MainWindow
from openjournal.ui.AboutWindow import Ui_AboutWindow


class AboutWindow(QMainWindow, Ui_AboutWindow):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.setupUi(self)

        # centers window
        qt_rectangle = self.frameGeometry()
        center_point = QDesktopWidget().availableGeometry().center()
        qt_rectangle.moveCenter(center_point)
        self.move(qt_rectangle.topLeft())


class MainWindow(QMainWindow, Ui_MainWindow):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.setupUi(self)

        # centers window
        qt_rectangle = self.frameGeometry()
        center_point = QDesktopWidget().availableGeometry().center()
        qt_rectangle.moveCenter(center_point)
        self.move(qt_rectangle.topLeft())

        # in app buttons
        self.newBtn.clicked.connect(self.handleNewJournal)
        self.openBtn.clicked.connect(self.handleOpenJournal)
        self.saveBtn.clicked.connect(self.handleSaveJournal)
        self.encryptBtn.clicked.connect(self.handleEncrypt)
        self.decryptBtn.clicked.connect(self.handleDecrypt)
        self.export_keyBtn.clicked.connect(self.exportKey)
        self.deleteBtn.clicked.connect(self.handleDeleteJournal)
        self.closeBtn.clicked.connect(self.handleCloseJournal)

        # menubar buttons
        self.New.triggered.connect(self.handleNewJournal)
        self.Open.triggered.connect(self.handleOpenJournal)
        self.Save.triggered.connect(self.handleSaveJournal)
        self.Delete.triggered.connect(self.handleDeleteJournal)
        self.Encrypt_Journal.triggered.connect(self.handleEncrypt)
        self.Decrypt_Journal.triggered.connect(self.handleDecrypt)
        self.Export_key.triggered.connect(self.exportKey)
        self.Close.triggered.connect(self.handleCloseJournal)
        self.Exit.triggered.connect(self.onClose)

        self.About_Open_Journal.triggered.connect(self.handleAboutWindow)

        self.keyStatusWidget()  # check for key

        app.aboutToQuit.connect(self.onClose)

    def onClose(self):
        """Auto-save journal before closing."""
        self.handleSaveJournal()
        sys.exit(0)

    def handleNewJournal(self):
        """Create a new journal. If no journal open but text typed, it will be saved."""
        # save current journal, if applicable
        self.handleSaveJournal()

        options = QFileDialog.Options()
        options |= QFileDialog.DontUseNativeDialog
        filename, _ = QFileDialog.getSaveFileName(self, "Save New Journal Entry As...",
                                                  "./journals/.txt",
                                                  "All Files (*)",
                                                  options=options)

        try:
            if filename != '':
                if self.journalName.text() != '':
                    # clear previous journal
                    self.journalName.clear()
                    self.journalEdit.clear()

                self.journalName.setText(filename)
                file = open(filename, 'w')
                text = self.journalEdit.toPlainText()
                file.write(text)
                file.close()
        except FileNotFoundError:
            pass

    def handleOpenJournal(self):
        """Open an existing journal."""
        # save current journal, if applicable
        self.handleSaveJournal()

        options = QFileDialog.Options()
        options |= QFileDialog.DontUseNativeDialog
        filename, _ = QFileDialog.getOpenFileName(self, "Open Journal Entry",
                                                  "./journals",
                                                  "All Files (*)",
                                                  options=options)

        try:
            if filename != '':
                self.journalName.setText(filename)
                with open(filename) as file:
                    data = file.read()
                    self.journalEdit.setText(data)
        except FileNotFoundError:
            pass

    def handleCloseJournal(self):
        """Close currently open journal."""
        self.handleSaveJournal()

        try:
            filename = self.journalName.text()
            if filename != '':
                self.journalName.clear()
                self.journalEdit.clear()
            else:
                self.statusbar.showMessage('No journal currently open.', 2000)
        except FileNotFoundError:
            pass

    def handleSaveJournal(self):
        """Save currently open journal."""
        try:
            filename = self.journalName.text()
            file = open(filename, 'w')
            text = self.journalEdit.toPlainText()
            file.write(text)
            self.statusbar.showMessage(f"Saving '{filename}'...", 2000)
            file.close()
        except FileNotFoundError:
            pass

    def createKey(self):
        """Generates encryption key and saves to file."""
        if self.checkKeyStatus():
            return open('open_journal_key.key', 'rb').read()
        else:
            key = Fernet.generate_key()
            with open('open_journal_key.key', 'wb') as key_file:
                key_file.write(key)

            self.exportKey()
            return open('open_journal_key.key', 'rb').read()

    def exportKey(self):
        """Copies encryption key to selected directory."""
        if self.checkKeyStatus():
            notice = QMessageBox()
            notice.setIcon(QMessageBox.Information)
            notice.setWindowTitle('Export Key')
            notice.setText('Save your encryption key to a safe place and keep it backed up.\n'
                           '\nOnly one key is used to encrypt journals. If you lose this key, you will not'
                           ' be able to recover any encrypted journals.')
            notice.setStandardButtons(QMessageBox.Ok)
            notice.exec_()
            try:
                options = QFileDialog.Options()
                options |= QFileDialog.DontUseNativeDialog
                filename, _ = QFileDialog.getSaveFileName(self, "Export Encryption Key",
                                                          "./open_journal_key.key",
                                                          "All Files (*)",
                                                          options=options)

                if filename != '':
                    shutil.copy('open_journal_key.key', filename)
            except FileNotFoundError:
                pass
        else:
            self.loadKey()

    def loadKey(self):
        """Attempts to load key from root program directory, otherwise prompts user for location."""
        if self.checkKeyStatus():
            return open('open_journal_key.key', 'rb').read()
        else:
            try:
                key_options = QMessageBox()
                key_options.setIcon(QMessageBox.Question)

                key_options.setWindowTitle('Create Or Load Key')
                key_options.setText('No key was found in the program directory.')
                key_options.setInformativeText('Would you like to create a key or load an existing key?\n'
                                               '\nNote: You only need to create a key once.')
                key_options.addButton(QPushButton('Load Key'), QMessageBox.YesRole)
                key_options.addButton(QPushButton('Create Key'), QMessageBox.YesRole)
                key_options.addButton(QPushButton('Cancel'), QMessageBox.RejectRole)
                return_value = key_options.exec_()
                if return_value == 0:  # 0 refers to load key button
                    options = QFileDialog.Options()
                    options |= QFileDialog.DontUseNativeDialog
                    filename, _ = QFileDialog.getOpenFileName(self, "Load Encryption Key",
                                                              "./journals",
                                                              "All Files (*)",
                                                              "Key File (.key)",
                                                              options=options)

                    current_dir = os.getcwd()
                    shutil.copy(filename, current_dir)
                    old_key = os.path.basename(filename)
                    os.rename(old_key, r'open_journal_key.key')  # rename to expected name
                    return open(filename, 'rb').read()
                elif return_value == 1:  # 1 refers to create key button
                    self.createKey()
                elif return_value == 2:
                    pass
            except FileNotFoundError or TypeError:
                pass

    def checkKeyStatus(self):
        """Checks if an existing key is located in same location as program."""
        return os.path.exists('open_journal_key.key')

    def keyStatusWidget(self):
        """Displays key status in statusbar."""
        if self.checkKeyStatus():
            key_status = QLabel('Key loaded')
            key_status.setStyleSheet('border :1px solid white;'
                                     'background-color: rgb(115, 210, 22);')
            self.statusbar.addPermanentWidget(key_status)
        else:
            key_status = QLabel('Key not loaded')
            key_status.setStyleSheet('border :1px solid white;'
                                     'background-color: rgb(204, 0, 0);')
            self.statusbar.addPermanentWidget(key_status)

    def handleEncrypt(self):
        """Encrypts currently open journal."""
        try:
            key = self.loadKey()
            self.handleSaveJournal()

            filename = self.journalName.text()
            f = Fernet(key)

            # read journal file
            with open(filename, 'rb') as file:
                journal = file.read()

            # encrypt journal and write to file
            encrypted_journal = f.encrypt(journal)
            with open(filename, 'wb') as file:
                file.write(encrypted_journal)

            # display encrypted contents
            with open(filename) as now_encrypted:
                data = now_encrypted.read()
                self.journalEdit.setText(data)
        except FileNotFoundError:
            self.statusbar.showMessage('Encryption failed. No file currently open.', 2000)
        except TypeError:
            pass

    def handleDecrypt(self):
        """Decrypts currently open journal."""
        try:
            key = self.loadKey()
            self.handleSaveJournal()
            filename = self.journalName.text()
            f = Fernet(key)

            # read the journal file
            with open(filename, 'rb') as file:
                encrypted_journal = file.read()

            # decrypt the journal and write to file
            decrypted_journal = f.decrypt(encrypted_journal)
            with open(filename, 'wb') as file:
                file.write(decrypted_journal)

            # display decrypted contents
            with open(filename) as now_decrypted:
                data = now_decrypted.read()
                self.journalEdit.setText(data)
        except FileNotFoundError:
            self.statusbar.showMessage('Decryption failed. No file currently open.', 2000)
        except TypeError:
            pass

    def handleDeleteJournal(self):
        """Delete currently open journal."""
        try:
            filename = self.journalName.text()
            if filename != '':
                confirm = QMessageBox()
                confirm.setIcon(QMessageBox.Warning)
                confirm.setWindowTitle('Confirm Journal Deletion')
                confirm.setText('You are about to delete the currently opened journal.')
                confirm.setInformativeText('This action cannot be undone. Continue?')
                confirm.setStandardButtons(QMessageBox.Yes | QMessageBox.No)
                return_value = confirm.exec_()
                if return_value == QMessageBox.Yes:
                    os.remove(filename)
                    self.journalEdit.clear()
                    self.journalName.clear()
                else:
                    pass
            else:
                self.statusbar.showMessage('No journal open, nothing to delete.', 2000)
        except FileNotFoundError:
            pass

    def handleAboutWindow(self):
        about_window = AboutWindow(self)
        about_window.show()


app = QApplication(sys.argv)


def main():
    window = MainWindow()
    window.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(950, 1100)
        MainWindow.setMinimumSize(QtCore.QSize(950, 1100))
        MainWindow.setMaximumSize(QtCore.QSize(950, 1100))
        MainWindow.setStyleSheet("background-color: rgb(32, 74, 135);")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.logo = QtWidgets.QLabel(self.centralwidget)
        self.logo.setGeometry(QtCore.QRect(320, 0, 321, 81))
        font = QtGui.QFont()
        font.setFamily("Umpush")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(True)
        font.setWeight(50)
        self.logo.setFont(font)
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/resources/logo.png"))
        self.logo.setScaledContents(True)
        self.logo.setObjectName("logo")
        self.journalEdit = QtWidgets.QTextEdit(self.centralwidget)
        self.journalEdit.setGeometry(QtCore.QRect(60, 110, 881, 941))
        self.journalEdit.setStyleSheet("background-color: rgba(191, 64, 64, 0);\n"
"background: 1\n"
"")
        self.journalEdit.setObjectName("journalEdit")
        self.journalName = QtWidgets.QLineEdit(self.centralwidget)
        self.journalName.setGeometry(QtCore.QRect(160, 80, 781, 25))
        self.journalName.setStyleSheet("background: 1")
        self.journalName.setInputMethodHints(QtCore.Qt.ImhNone)
        self.journalName.setDragEnabled(False)
        self.journalName.setReadOnly(True)
        self.journalName.setObjectName("journalName")
        self.journal_path = QtWidgets.QLabel(self.centralwidget)
        self.journal_path.setGeometry(QtCore.QRect(60, 80, 91, 21))
        self.journal_path.setStyleSheet("border-color: rgb(255, 255, 255);\n"
"")
        self.journal_path.setObjectName("journal_path")
        self.saveBtn = QtWidgets.QPushButton(self.centralwidget)
        self.saveBtn.setGeometry(QtCore.QRect(5, 230, 48, 48))
        self.saveBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.saveBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.saveBtn.setStyleSheet("QPushButton {border-image: url(:/resources/save.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};")
        self.saveBtn.setText("")
        self.saveBtn.setObjectName("saveBtn")
        self.deleteBtn = QtWidgets.QPushButton(self.centralwidget)
        self.deleteBtn.setGeometry(QtCore.QRect(5, 470, 48, 48))
        self.deleteBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.deleteBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.deleteBtn.setStyleSheet("QPushButton {border-image: url(:/resources/delete.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};")
        self.deleteBtn.setText("")
        self.deleteBtn.setObjectName("deleteBtn")
        self.openBtn = QtWidgets.QPushButton(self.centralwidget)
        self.openBtn.setGeometry(QtCore.QRect(5, 170, 48, 48))
        self.openBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.openBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.openBtn.setStyleSheet("QPushButton {border-image: url(:/resources/open.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};\n"
"")
        self.openBtn.setText("")
        self.openBtn.setObjectName("openBtn")
        self.encryptBtn = QtWidgets.QPushButton(self.centralwidget)
        self.encryptBtn.setGeometry(QtCore.QRect(5, 290, 48, 48))
        self.encryptBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.encryptBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.encryptBtn.setStyleSheet("QPushButton {border-image: url(:/resources/encrypt.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};")
        self.encryptBtn.setText("")
        self.encryptBtn.setObjectName("encryptBtn")
        self.decryptBtn = QtWidgets.QPushButton(self.centralwidget)
        self.decryptBtn.setGeometry(QtCore.QRect(5, 350, 48, 48))
        self.decryptBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.decryptBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.decryptBtn.setStyleSheet("QPushButton {border-image: url(:/resources/decrypt.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};")
        self.decryptBtn.setText("")
        self.decryptBtn.setObjectName("decryptBtn")
        self.newBtn = QtWidgets.QPushButton(self.centralwidget)
        self.newBtn.setGeometry(QtCore.QRect(5, 110, 48, 48))
        self.newBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.newBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.newBtn.setStyleSheet("QPushButton {border-image: url(:/resources/new.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};\n"
"")
        self.newBtn.setText("")
        self.newBtn.setObjectName("newBtn")
        self.closeBtn = QtWidgets.QPushButton(self.centralwidget)
        self.closeBtn.setGeometry(QtCore.QRect(5, 530, 48, 48))
        self.closeBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.closeBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.closeBtn.setStyleSheet("QPushButton {border-image: url(:/resources/close.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};")
        self.closeBtn.setText("")
        self.closeBtn.setObjectName("closeBtn")
        self.export_keyBtn = QtWidgets.QPushButton(self.centralwidget)
        self.export_keyBtn.setGeometry(QtCore.QRect(5, 410, 48, 48))
        self.export_keyBtn.setMinimumSize(QtCore.QSize(48, 48))
        self.export_keyBtn.setMaximumSize(QtCore.QSize(48, 48))
        self.export_keyBtn.setStyleSheet("QPushButton {border-image: url(:/resources/export_key.png)}\n"
"QToolTip {    background-color: rgb(238, 238, 236);\n"
"                           color: black; \n"
"                           border: black solid 1px};")
        self.export_keyBtn.setText("")
        self.export_keyBtn.setObjectName("export_keyBtn")
        self.logo.raise_()
        self.journalName.raise_()
        self.journal_path.raise_()
        self.saveBtn.raise_()
        self.deleteBtn.raise_()
        self.openBtn.raise_()
        self.encryptBtn.raise_()
        self.decryptBtn.raise_()
        self.newBtn.raise_()
        self.journalEdit.raise_()
        self.closeBtn.raise_()
        self.export_keyBtn.raise_()
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 950, 22))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        self.menubar.setPalette(palette)
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        self.menuFile.setPalette(palette)
        self.menuFile.setObjectName("menuFile")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        self.menuHelp.setPalette(palette)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ToolTipText, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236, 128))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.PlaceholderText, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ToolTipText, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236, 128))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.PlaceholderText, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(32, 74, 135))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(238, 238, 236))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ToolTipText, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0, 128))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.PlaceholderText, brush)
        self.statusbar.setPalette(palette)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionNew = QtWidgets.QAction(MainWindow)
        self.actionNew.setObjectName("actionNew")
        self.New = QtWidgets.QAction(MainWindow)
        self.New.setObjectName("New")
        self.Open = QtWidgets.QAction(MainWindow)
        self.Open.setObjectName("Open")
        self.Save = QtWidgets.QAction(MainWindow)
        self.Save.setObjectName("Save")
        self.Save_As = QtWidgets.QAction(MainWindow)
        self.Save_As.setObjectName("Save_As")
        self.About_Open_Journal = QtWidgets.QAction(MainWindow)
        self.About_Open_Journal.setObjectName("About_Open_Journal")
        self.Encrypt_Journal = QtWidgets.QAction(MainWindow)
        self.Encrypt_Journal.setObjectName("Encrypt_Journal")
        self.Decrypt_Journal = QtWidgets.QAction(MainWindow)
        self.Decrypt_Journal.setObjectName("Decrypt_Journal")
        self.Preferences = QtWidgets.QAction(MainWindow)
        self.Preferences.setObjectName("Preferences")
        self.Print = QtWidgets.QAction(MainWindow)
        self.Print.setObjectName("Print")
        self.Exit = QtWidgets.QAction(MainWindow)
        self.Exit.setShortcut("")
        self.Exit.setObjectName("Exit")
        self.Delete = QtWidgets.QAction(MainWindow)
        self.Delete.setObjectName("Delete")
        self.Close = QtWidgets.QAction(MainWindow)
        self.Close.setObjectName("Close")
        self.Export_key = QtWidgets.QAction(MainWindow)
        self.Export_key.setObjectName("Export_key")
        self.menuFile.addAction(self.New)
        self.menuFile.addAction(self.Open)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.Save)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.Delete)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.Encrypt_Journal)
        self.menuFile.addAction(self.Decrypt_Journal)
        self.menuFile.addAction(self.Export_key)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.Close)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.Exit)
        self.menuHelp.addAction(self.About_Open_Journal)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Open Journal"))
        self.journalName.setToolTip(_translate("MainWindow", "<html><head/><body><p>Displays the filepath to the currently open journal.</p></body></html>"))
        self.journalName.setPlaceholderText(_translate("MainWindow", "No journal currently open. Create a new journal (plus icon) or open an existing one (folder icon)."))
        self.journal_path.setText(_translate("MainWindow", "<html><head/><body><p><span style=\" color:#eeeeec;\">Journal Path:</span></p></body></html>"))
        self.saveBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Save journal (Ctrl + S)</p></body></html>"))
        self.deleteBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Delete journal</p></body></html>"))
        self.openBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Open existing journal (Ctrl + O)</p></body></html>"))
        self.encryptBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Encrypt currently open journal</p></body></html>"))
        self.decryptBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Decrypt currently open journal</p></body></html>"))
        self.newBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Create new journal (Ctrl + N)</p><p><br/></p></body></html>"))
        self.closeBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Save and close journal</p></body></html>"))
        self.export_keyBtn.setToolTip(_translate("MainWindow", "<html><head/><body><p>Export encryption key</p></body></html>"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.actionNew.setText(_translate("MainWindow", "New"))
        self.New.setText(_translate("MainWindow", "New"))
        self.New.setToolTip(_translate("MainWindow", "Create new journal"))
        self.New.setShortcut(_translate("MainWindow", "Ctrl+N"))
        self.Open.setText(_translate("MainWindow", "Open"))
        self.Open.setToolTip(_translate("MainWindow", "Open existing journal"))
        self.Open.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.Save.setText(_translate("MainWindow", "Save"))
        self.Save.setToolTip(_translate("MainWindow", "Save journal"))
        self.Save.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.Save_As.setText(_translate("MainWindow", "Save As..."))
        self.About_Open_Journal.setText(_translate("MainWindow", "About Open Journal"))
        self.Encrypt_Journal.setText(_translate("MainWindow", "Encrypt Journal"))
        self.Encrypt_Journal.setToolTip(_translate("MainWindow", "Encrypt currently open journal"))
        self.Decrypt_Journal.setText(_translate("MainWindow", "Decrypt Journal"))
        self.Decrypt_Journal.setToolTip(_translate("MainWindow", "Decrypt currently open journal"))
        self.Preferences.setText(_translate("MainWindow", "Preferences"))
        self.Print.setText(_translate("MainWindow", "Print"))
        self.Print.setToolTip(_translate("MainWindow", "Print journal"))
        self.Print.setShortcut(_translate("MainWindow", "Ctrl+P"))
        self.Exit.setText(_translate("MainWindow", "Exit"))
        self.Delete.setText(_translate("MainWindow", "Delete Journal"))
        self.Close.setText(_translate("MainWindow", "Close Journal"))
        self.Export_key.setText(_translate("MainWindow", "Export encryption key"))
import openjournal.ui.resources_rc



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='open-journal',
    version='1.0.0',
    install_requires=[
    	'pyqt5',
    	'cryptography'
    ],
    packages=find_packages(),
    scripts=['openjournal/main.py'],
    url='https://github.com/Optimizer-Prime/open-journal',
    license='GPL-3.0',
    author='Stuart Clayton',
    author_email='stu3cla@pm.me',
    description='A simple, private, open-source journal.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=["Programming Language :: Python :: 3"],
    python_requires='>=3.6',
    entry_points = {
    'gui_scripts': [
        'openjournal=openjournal.main:main']
        }
)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'aboutwindow.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_AboutWindow(object):
    def setupUi(self, AboutWindow):
        AboutWindow.setObjectName("AboutWindow")
        AboutWindow.resize(620, 495)
        AboutWindow.setMinimumSize(QtCore.QSize(620, 495))
        AboutWindow.setMaximumSize(QtCore.QSize(620, 495))
        self.centralwidget = QtWidgets.QWidget(AboutWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.logo = QtWidgets.QLabel(self.centralwidget)
        self.logo.setGeometry(QtCore.QRect(140, 0, 331, 91))
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/resources/logo.png"))
        self.logo.setScaledContents(True)
        self.logo.setObjectName("logo")
        self.info = QtWidgets.QLabel(self.centralwidget)
        self.info.setGeometry(QtCore.QRect(20, 110, 581, 341))
        font = QtGui.QFont()
        font.setPointSize(14)
        self.info.setFont(font)
        self.info.setAlignment(QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop)
        self.info.setObjectName("info")
        AboutWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(AboutWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 620, 22))
        self.menubar.setObjectName("menubar")
        AboutWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(AboutWindow)
        self.statusbar.setObjectName("statusbar")
        AboutWindow.setStatusBar(self.statusbar)

        self.retranslateUi(AboutWindow)
        QtCore.QMetaObject.connectSlotsByName(AboutWindow)

    def retranslateUi(self, AboutWindow):
        _translate = QtCore.QCoreApplication.translate
        AboutWindow.setWindowTitle(_translate("AboutWindow", "About Open Journal"))
        self.info.setText(_translate("AboutWindow", "<html><head/><body><p>Open Journal v1.0.0</p><p><br/></p><p>Simple, private, open-source journal for linux.</p><p><br/></p><p>For more information visit: </p><p><a href=\"https://github.com/Optimizer-Prime/open-journal\"><span style=\" text-decoration: underline; color:#eeeeec;\">https://github.com/Optimizer-Prime/open-journal</span></a></p><p><br/>Licensed under GPL-3.0</p><p><span style=\" color:#000000;\">Copyright 2020 Stuart Clayton</span></p></body></html>"))

import openjournal.ui.resources_rc
